==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/backup/index.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>Backup</title>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<meta name="keywords" content="" />
<meta name="description" content="" />
<link href="../assets/css/styles.css" rel="stylesheet" type="text/css" media="screen" />
<link href="../assets/css/menu.css" media="screen" rel="stylesheet" type="text/css" />
<script src="../assets/js/jquery-min.js" type="text/javascript"></script>
</head>
<body>
<?php
$script=$_SERVER['SCRIPT_NAME']; 	$url = $_SERVER['SERVER_ADDR'];
$action = (isset ($_REQUEST['action'] )) ? $_REQUEST['action'] : "0";
?>
<div id="content">

<div class="logo">
<a href="#"><img src='../assets/images/logo.png'></img></a>
</div>

<div id="wrap">

<!-- header begins -->
<div class="menu-wrap">
<?php
	require('../assets/inc/header.php');
	if ($adminCompany != '00000000-0000-0000-0000-000000000000') {  header("Location: ../"); exit(); }

?>	
</div>
<!-- header ends -->


<div id="main">
<div class="wrapper">
<!-- content begins -->
<h3><span class="icon-floppy-disk greyicon"></span> Backup</h3>
<?php

$ds=ldap_connect("127.0.0.1",4000);
$r=ldap_bind($ds,"INTERNAL","0123456");
$sr = ldap_read($ds,"cn=System","objectclass=*"); $info = ldap_get_entries($ds,$sr);
$sysname=str_replace(' ','',(substr($info[0]['administrationdomain'][0],0,10))); $backup = $sysname."-Backup-".date('d.m.y-His').".txt";
echo "Backup Requested<br/><br/>";
echo "File Name is : <b>".$backup."</b><br/><br/>";
echo "This file is located in '/SpliceCom/ftp/'<br/>";
echo "<i>(the file name is based on the first 10 characters of the system name)</i><br/><br/>";
echo "<br/><span style='color:#d90000; font-weight: bold;'>PLEASE NOTE: Do not navigate away from this page until the back up has completed.</span><br/><br/>";
echo "<div id='loader'><img src='../assets/images/save_banner.gif'/></div>";

@ob_flush(); @flush();

$ent["dobackupto"] = "../ftp/$backup";
touch ("/SpliceCom/ftp/$backup");
chmod ("/SpliceCom/ftp/$backup",0644);
ldap_modify($ds,"cn=Commands",$ent);

$old = 0; $new = 1;
$filePath = "/SpliceCom/ftp/$backup";
while ($old != $new) {
	$old = filesize ($filePath);
	clearstatcache();
    sleep(1);
    $new = filesize ($filePath);
    clearstatcache();
}

sleep(2);

@ob_flush(); @flush();
echo "Consolidating Backup File<br/>";

ldap_modify($ds,"cn=Commands",$ent);

$old = 0; $new = 1;
$filePath = "/SpliceCom/ftp/$backup";
while ($old != $new) {
	$old = filesize ($filePath);
	clearstatcache();
    sleep(1);
    $new = filesize ($filePath);
    clearstatcache();
}

ldap_close($ds);

@ob_flush(); @flush();
echo "Backup Done<br/><br/>";
echo "<script> document.getElementById('loader').style.display = 'none'; </script>";

audit ("[Backup] [Created] $backup");
?>

<!--content ends -->
</div>
</div>	

<!--footer begins -->
<?php
	require('../assets/inc/footer.php');
?>
<!-- footer ends-->
</div>

</div>
</body>
</html>

==> SV1000-Linux.SV1.3.117.tar.gz: SpliceCom/WebManager/admin/backup/index.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>Backup</title>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<meta name="keywords" content="" />
<meta name="description" content="" />
<link href="../assets/css/styles.css" rel="stylesheet" type="text/css" media="screen" />
<link href="../assets/css/menu.css" media="screen" rel="stylesheet" type="text/css" />
<script src="../assets/js/jquery-min.js" type="text/javascript"></script>
</head>
<body>
<?php
$script=$_SERVER['SCRIPT_NAME']; 	$url = $_SERVER['SERVER_ADDR'];
$action = (isset ($_REQUEST['action'] )) ? $_REQUEST['action'] : "0";
?>
<div id="content">

<div class="logo">
<a href="#"><img src='../assets/images/logo.png'></img></a>
</div>

<div id="wrap">

<!-- header begins -->
<div class="menu-wrap">
<?php
	require('../assets/inc/header.php');
	if ($adminCompany != '00000000-0000-0000-0000-000000000000') {  header("Location: ../"); exit(); }

?>	
</div>
<!-- header ends -->


<div id="main">
<div class="wrapper">
<!-- content begins -->
<h3><span class="icon-floppy-disk greyicon"></span> Backup</h3>
<?php

$ds=ldap_connect("127.0.0.1",4000);
$r=ldap_bind($ds,"INTERNAL","0123456");
$sr = ldap_read($ds,"cn=System","objectclass=*"); $info = ldap_get_entries($ds,$sr);
$sysname=str_replace(' ','',(substr($info[0]['administrationdomain'][0],0,10))); $backup = $sysname."-Backup-".date('d.m.y-His').".txt";
echo "Backup Requested<br/><br/>";
echo "File Name is : <b>".$backup."</b><br/><br/>";
echo "This file is located in '/SpliceCom/ftp/'<br/>";
echo "<i>(the file name is based on the first 10 characters of the system name)</i><br/><br/>";
echo "<br/><span style='color:#d90000; font-weight: bold;'>PLEASE NOTE: Do not navigate away from this page until the back up has completed.</span><br/><br/>";
echo "<div id='loader'><img src='../assets/images/save_banner.gif'/></div>";

@ob_flush(); @flush();

$ent["dobackupto"] = "../ftp/$backup";
touch ("/SpliceCom/ftp/$backup");
chmod ("/SpliceCom/ftp/$backup",0644);
ldap_modify($ds,"cn=Commands",$ent);

$old = 0; $new = 1;
$filePath = "/SpliceCom/ftp/$backup";
while ($old != $new) {
	$old = filesize ($filePath);
	clearstatcache();
    sleep(1);
    $new = filesize ($filePath);
    clearstatcache();
}

sleep(2);

@ob_flush(); @flush();
echo "Consolidating Backup File<br/>";

ldap_modify($ds,"cn=Commands",$ent);

$old = 0; $new = 1;
$filePath = "/SpliceCom/ftp/$backup";
while ($old != $new) {
	$old = filesize ($filePath);
	clearstatcache();
    sleep(1);
    $new = filesize ($filePath);
    clearstatcache();
}

ldap_close($ds);

@ob_flush(); @flush();
echo "Backup Done<br/><br/>";
echo "<script> document.getElementById('loader').style.display = 'none'; </script>";

$timestamp = time();
audit ($timestamp, "[Backup] [Created] $backup", "Backup file $backup generated");
?>

<!--content ends -->
</div>
</div>	

<!--footer begins -->
<?php
	require('../assets/inc/footer.php');
?>
<!-- footer ends-->
</div>

</div>
</body>
</html>
